@@ -3,5 +3,5 @@ hwid = ["software"]
 class instrument:
     def __init__(self,port):
         pass
-    def gather(self):
+    def gather_data(self):
         return 1, 2
