@@ -11,7 +11,12 @@ except:
         "Stellarnet doesn't let people distribute stellarnet.py. The repository which has it https://github.com/acpo/PiSpec20_LED_stellarnet took it down at their request and there is absolutely no way to look at old git commits")
 import matplotlib as mpl
 
-mpl.use('Qt5Agg')
+#try:
+#    mpl.use('Qt5Agg')
+#except:
+#    mpl.use("Agg")
+#    print("falling back to headless")
+# Work headless
 import matplotlib.pyplot as plt
 from matplotlib.animation import FuncAnimation
 import numpy as np
